@@ -5,18 +5,17 @@
 (provide 'libc.scm)
 
 ;; if loading from a different directory, pass that info to C
-(let ((current-file (port-filename (current-input-port))))
-  (let ((directory (and (or (char=? (current-file 0) #\/)
-			    (char=? (current-file 0) #\~))
-			(substring current-file 0 (- (length current-file) 9)))))
-    (when (and directory (not (member directory *load-path*)))
-      (set! *load-path* (cons directory *load-path*)))
-    (with-let (rootlet)
-      (require cload.scm))
-    (when (and directory (not (string-position directory *cload-cflags*)))
-      (set! *cload-cflags* (string-append "-I" directory " " *cload-cflags*)))))
+(let ((directory (let ((current-file (port-filename)))
+		   (and (memv (current-file 0) '(#\/ #\~))
+			(substring current-file 0 (- (length current-file) 9))))))
+  (when (and directory (not (member directory *load-path*)))
+    (set! *load-path* (cons directory *load-path*)))
+  (with-let (rootlet)
+    (require cload.scm))
+  (when (and directory (not (string-position directory *cload-cflags*)))
+    (set! *cload-cflags* (string-append "-I" directory " " *cload-cflags*))))
 
-(if (not (defined? '*libc*))
+(unless (defined? '*libc*)
     (define *libc*
       (with-let (unlet)
 	(set! *libraries* (cons (cons "libc.scm" (curlet)) *libraries*))
@@ -154,9 +153,9 @@
                         if (s7_is_integer(s7_car(arg)))
                           mode = (int)s7_integer(s7_car(arg));
                         else return(s7_wrong_type_arg_error(sc, \"open\", 3, s7_car(arg), \"integer\"));
-                        return(s7_make_integer(sc, (s7_Int)open(name, flags, mode)));
+                        return(s7_make_integer(sc, (s7_int)open(name, flags, mode)));
                        }
-                     return(s7_make_integer(sc, (s7_Int)open(name, flags)));
+                     return(s7_make_integer(sc, (s7_int)open(name, flags)));
                     }")
 	   (C-function ("open" g_c_open "" 2 1))
 	   (int creat (char* (mode_t int)))
@@ -223,9 +222,7 @@
 	   (int remove (char*))
 	   (int rename (char* char*))
 	   (FILE* tmpfile (void))
-	   (reader-cond ((not (provided? 'osx)) 
-			 (char* tmpnam (char*))
-			 (char* tempnam (char* char*))))
+;	   (reader-cond ((not (provided? 'osx)) (char* tmpnam (char*)) (char* tempnam (char* char*))))
 	   (int fclose (FILE*))
 	   (int fflush (FILE*))
 	   ;;		    (reader-cond ((provided? 'linux) (int fcloseall (void))))
@@ -304,7 +301,7 @@
 	   (int putenv (char*))
 	   (int setenv (char* char* int))
 	   (int unsetenv (char*))
-	   (char* mktemp (char*))
+;	   (char* mktemp (char*))
 	   (int mkstemp (char*))
 	   (int system (char*))
 	   (char* realpath (char* char*))
@@ -373,26 +370,26 @@
              {
                struct lconv *lc;
                lc = localeconv();
-               return(s7_list(sc, 18,
-             		     s7_cons(sc, s7_make_symbol(sc, \"decimal_point\"),     s7_make_string(sc, lc->decimal_point)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"thousands_sep\"),     s7_make_string(sc, lc->thousands_sep)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"grouping\"),          s7_make_string(sc, lc->grouping)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"int_curr_symbol\"),   s7_make_string(sc, lc->int_curr_symbol)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"currency_symbol\"),   s7_make_string(sc, lc->currency_symbol)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"mon_decimal_point\"), s7_make_string(sc, lc->mon_decimal_point)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"mon_thousands_sep\"), s7_make_string(sc, lc->mon_thousands_sep)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"mon_grouping\"),      s7_make_string(sc, lc->mon_grouping)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"positive_sign\"),     s7_make_string(sc, lc->positive_sign)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"negative_sign\"),     s7_make_string(sc, lc->negative_sign)),
+               return(s7_inlet(sc, s7_list(sc, 36,
+             		     s7_make_symbol(sc, \"decimal_point\"),     s7_make_string(sc, lc->decimal_point),
+             		     s7_make_symbol(sc, \"thousands_sep\"),     s7_make_string(sc, lc->thousands_sep),
+             		     s7_make_symbol(sc, \"grouping\"),          s7_make_string(sc, lc->grouping),
+             		     s7_make_symbol(sc, \"int_curr_symbol\"),   s7_make_string(sc, lc->int_curr_symbol),
+             		     s7_make_symbol(sc, \"currency_symbol\"),   s7_make_string(sc, lc->currency_symbol),
+             		     s7_make_symbol(sc, \"mon_decimal_point\"), s7_make_string(sc, lc->mon_decimal_point),
+             		     s7_make_symbol(sc, \"mon_thousands_sep\"), s7_make_string(sc, lc->mon_thousands_sep),
+             		     s7_make_symbol(sc, \"mon_grouping\"),      s7_make_string(sc, lc->mon_grouping),
+             		     s7_make_symbol(sc, \"positive_sign\"),     s7_make_string(sc, lc->positive_sign),
+             		     s7_make_symbol(sc, \"negative_sign\"),     s7_make_string(sc, lc->negative_sign),
              		     
-             		     s7_cons(sc, s7_make_symbol(sc, \"int_frac_digits\"),   s7_make_integer(sc, lc->int_frac_digits)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"frac_digits\"),       s7_make_integer(sc, lc->frac_digits)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"p_cs_precedes\"),     s7_make_integer(sc, lc->p_cs_precedes)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"p_sep_by_space\"),    s7_make_integer(sc, lc->p_sep_by_space)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"n_cs_precedes\"),     s7_make_integer(sc, lc->n_cs_precedes)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"n_sep_by_space\"),    s7_make_integer(sc, lc->n_sep_by_space)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"p_sign_posn\"),       s7_make_integer(sc, lc->p_sign_posn)),
-             		     s7_cons(sc, s7_make_symbol(sc, \"n_sign_posn\"),       s7_make_integer(sc, lc->n_sign_posn))));
+             		     s7_make_symbol(sc, \"int_frac_digits\"),   s7_make_integer(sc, lc->int_frac_digits),
+             		     s7_make_symbol(sc, \"frac_digits\"),       s7_make_integer(sc, lc->frac_digits),
+             		     s7_make_symbol(sc, \"p_cs_precedes\"),     s7_make_integer(sc, lc->p_cs_precedes),
+             		     s7_make_symbol(sc, \"p_sep_by_space\"),    s7_make_integer(sc, lc->p_sep_by_space),
+             		     s7_make_symbol(sc, \"n_cs_precedes\"),     s7_make_integer(sc, lc->n_cs_precedes),
+             		     s7_make_symbol(sc, \"n_sep_by_space\"),    s7_make_integer(sc, lc->n_sep_by_space),
+             		     s7_make_symbol(sc, \"p_sign_posn\"),       s7_make_integer(sc, lc->p_sign_posn),
+             		     s7_make_symbol(sc, \"n_sign_posn\"),       s7_make_integer(sc, lc->n_sign_posn))));
               }")
 	   (C-function ("localeconv" g_localeconv "" 0))
 	   
@@ -696,7 +693,7 @@
 	   
 	   (in-C "static s7_pointer g_mktime(s7_scheme *sc, s7_pointer args) 
                   {
-                    return(s7_make_integer(sc, (s7_Int)mktime((struct tm *)s7_c_pointer(s7_car(args)))));
+                    return(s7_make_integer(sc, (s7_int)mktime((struct tm *)s7_c_pointer(s7_car(args)))));
                   }
                   static s7_pointer g_time_make(s7_scheme *sc, s7_pointer args) 
                   {
@@ -707,7 +704,7 @@
                   }
                   static s7_pointer g_strftime(s7_scheme *sc, s7_pointer args) 
                   {
-                    return(s7_make_integer(sc, (s7_Int)strftime((char *)s7_string(s7_car(args)), 
+                    return(s7_make_integer(sc, (s7_int)strftime((char *)s7_string(s7_car(args)), 
                   				             (size_t)s7_integer(s7_cadr(args)), 
                   					     s7_string(s7_caddr(args)), 
                   					     (const struct tm *)s7_c_pointer(s7_cadddr(args)))));
@@ -767,7 +764,7 @@
                     #if __linux__
                     clockid_t c = 0;
                     clock_getcpuclockid((pid_t)s7_integer(s7_car(args)), &c);
-                    return(s7_make_integer(sc, (s7_Int)c));
+                    return(s7_make_integer(sc, (s7_int)c));
                     #else
                     return(s7_make_integer(sc, -1));
                     #endif
@@ -824,13 +821,13 @@
                   {
                     struct termios *p;
                     p = (struct termios *)s7_c_pointer(s7_car(args));
-                    return(s7_make_integer(sc, (s7_Int)cfgetospeed(p)));
+                    return(s7_make_integer(sc, (s7_int)cfgetospeed(p)));
                   }
                   static s7_pointer g_cfgetispeed(s7_scheme *sc, s7_pointer args)
                   {
                     struct termios *p;
                     p = (struct termios *)s7_c_pointer(s7_car(args));
-                    return(s7_make_integer(sc, (s7_Int)cfgetispeed(p)));
+                    return(s7_make_integer(sc, (s7_int)cfgetispeed(p)));
                   }
                   static s7_pointer g_cfsetospeed(s7_scheme *sc, s7_pointer args)
                   {
@@ -863,7 +860,7 @@
                   {
                     struct termios *p;
                     p = (struct termios *)s7_c_pointer(s7_car(args));
-                    return(s7_make_integer(sc, (s7_Int)(p->c_lflag)));
+                    return(s7_make_integer(sc, (s7_int)(p->c_lflag)));
                   }
                   static s7_pointer g_termios_set_c_lflag(s7_scheme *sc, s7_pointer args)
                   {
@@ -903,7 +900,7 @@
                   static s7_pointer g_group_gr_passwd(s7_scheme *sc, s7_pointer args) 
                     {return(s7_make_string(sc, ((struct group *)s7_c_pointer(s7_car(args)))->gr_passwd));}
                   static s7_pointer g_group_gr_gid(s7_scheme *sc, s7_pointer args) 
-                    {return(s7_make_integer(sc, (s7_Int)(((struct group *)s7_c_pointer(s7_car(args)))->gr_gid)));}
+                    {return(s7_make_integer(sc, (s7_int)(((struct group *)s7_c_pointer(s7_car(args)))->gr_gid)));}
                   static s7_pointer g_group_gr_mem(s7_scheme *sc, s7_pointer args)
                     {
                       s7_pointer p;
@@ -1537,7 +1534,7 @@
                     socklen_t res;
                     res = (socklen_t)s7_integer(s7_list_ref(sc, args, 4));
                     err = getsockopt(s7_integer(s7_car(args)), s7_integer(s7_cadr(args)), s7_integer(s7_caddr(args)), s7_c_pointer(s7_cadddr(args)), &res);
-                    return(s7_list(sc, 2, s7_make_integer(sc, err), s7_make_integer(sc, (s7_Int)res)));
+                    return(s7_list(sc, 2, s7_make_integer(sc, err), s7_make_integer(sc, (s7_int)res)));
                   }
                   static s7_pointer g_setsockopt(s7_scheme *sc, s7_pointer args) 
                   {
@@ -1557,7 +1554,7 @@
                   		 s7_integer(s7_cadddr(args)), 
                   		 (struct sockaddr *)s7_c_pointer(s7_list_ref(sc, args, 4)),
                   		 &res);
-                    return(s7_list(sc, 2, s7_make_integer(sc, err), s7_make_integer(sc, (s7_Int)res)));
+                    return(s7_list(sc, 2, s7_make_integer(sc, err), s7_make_integer(sc, (s7_int)res)));
                   }
 
                   static s7_pointer g_hostent_h_name(s7_scheme *sc, s7_pointer args)
