@@ -9,28 +9,25 @@
 
 (provide 'snd-musglyphs.scm)
 
-(define make-polygon
-  (lambda (args)
-    (define (total-length vects len)
-      (cond ((null? vects)         len)
-	    ((vector? (car vects)) (total-length (cdr vects) (+ len (length (car vects)))))
-	    ((car vects)           (total-length (cdr vects) (+ len 1)))
-	    (else                  (total-length (cdr vects) len))))
-    (let set-vals ((vects args) 
-		   (start 0) 
-		   (vals (make-vector (total-length args 0))))
-      (cond ((null? vects) vals)
-	    ((vector? (car vects))
-	     (let ((vect (car vects)))
-	       (do ((len (length vect))
-		    (i 0 (+ 1 i)))
-		   ((= i len)
-		    (set-vals (cdr vects) (+ start len) vals))
-		 (set! (vals (+ start i)) (vect i)))))
-	    ((car vects)
-	     (set! (vals start) (car vects))
-	     (set-vals (cdr vects) (+ start 1) vals))
-	    (else (set-vals (cdr vects) start vals))))))
+(define (make-polygon args)
+  (let set-vals ((vects args)
+		 (start 0)
+		 (vals (make-vector (let total-length ((vects args) (len 0))
+				      (cond ((null? vects)         len)
+					    ((vector? (car vects)) (total-length (cdr vects) (+ len (length (car vects)))))
+					    ((car vects)           (total-length (cdr vects) (+ len 1)))
+					    (else                  (total-length (cdr vects) len)))))))
+    (cond ((null? vects) vals)
+	  ((vector? (car vects))
+	   (let ((vect (car vects)))
+	     (do ((len (length vect))
+		  (i 0 (+ 1 i)))
+		 ((= i len) (set-vals (cdr vects) (+ start len) vals))
+	       (set! (vals (+ start i)) (vect i)))))
+	  ((car vects)
+	   (set! (vals start) (car vects))
+	   (set-vals (cdr vects) (+ start 1) vals))
+	  (else (set-vals (cdr vects) start vals)))))
 
 (define (make-bezier-1 x0 y0 x1 y1 x2 y2 x3 y3 n)
   ;; creates a line-segment approximation of a bezier curve: n = number of segments
@@ -220,37 +217,36 @@
 ;	 (apply (setter sound-comment) (list #f snd))
 ;	 (apply (setter sound-comment) (list snd val))))))
 
-;(load "loop.scm") ; Rick's loop implementation (cm/src/loop.scm)
 (define progn begin)
 
 (load "cmn-glyphs.lisp")
 
-
-
 ;;; a portion of CMN here to make it easier to display notes
 
-(define (frequency->note-octave-and-accidental freq)
-  (define (frequency->pitch freq)
-    (floor (* 12 (+ (log (/ freq 16.351) 2) (/ 1.0 24)))))
-
-  (let* ((pitch (frequency->pitch freq))
-	 (pclass (modulo pitch 12)))
-    (let ((octave (floor (/ pitch 12)))
-	  (cclass (case pclass
-		    ((0 1) 0) ; c-sharp
-		    ((2) 1) 
-		    ((3 4) 2) ; e-flat
-		    ((5 6) 3) ; f-sharp
-		    ((7) 4) 
-		    ((8 9) 5) ; a-flat
-		    (else 6)))) ; b-flat
-      (list pclass octave 
-	    (if (memv pclass '(1 6))
-		:sharp
-		(and (memv pclass '(3 8 10)) 
-		     :flat))
-	    cclass
-	    pitch))))
+(define frequency->note-octave-and-accidental
+  (let ((frequency->pitch 
+	 (lambda (freq)
+	   (floor (* 12 (+ (log (/ freq 16.351) 2) 
+			   (/ 1.0 24)))))))
+    (lambda (freq)
+      (let* ((pitch (frequency->pitch freq))
+	     (pclass (modulo pitch 12)))
+	(let ((octave (floor (/ pitch 12)))
+	      (cclass (case pclass
+			((0 1) 0)   ; c-sharp
+			((2) 1) 
+			((3 4) 2)   ; e-flat
+			((5 6) 3)   ; f-sharp
+			((7) 4) 
+			((8 9) 5)   ; a-flat
+			(else 6)))) ; b-flat
+	  (list pclass octave 
+		(if (memv pclass '(1 6))
+		    :sharp
+		    (and (memv pclass '(3 8 10)) 
+			 :flat))
+		cclass
+		pitch))))))
 
 (define note-data->pclass car)
 (define note-data->octave cadr)
