@@ -7,17 +7,17 @@
 ;;; ---------------- gl-info ----------------
 (define gl-info
   ;; taken loosely from glxvisuals.c
-  (let ((documentation "(gl-info) prints out GL-related info"))
+  (let ((documentation "(gl-info) prints out GL-related info")
+	(class-of (lambda (n)
+		    (and (number? n)
+			 (cond ((= n (*motif* 'StaticGray)) "static-gray")
+			       ((= n (*motif* 'GrayScale)) "gray-scale")
+			       ((= n (*motif* 'StaticColor)) "static-color")
+			       ((= n (*motif* 'PseudoColor)) "pseudo-color")
+			       ((= n (*motif* 'TrueColor)) "true-color")
+			       ((= n (*motif* 'DirectColor)) "direct-color")
+			       (#t "??"))))))
     (lambda ()
-      (define (class-of n)
-	(and (number? n)
-	     (cond ((= n (*motif* 'StaticGray)) "static-gray")
-		   ((= n (*motif* 'GrayScale)) "gray-scale")
-		   ((= n (*motif* 'StaticColor)) "static-color")
-		   ((= n (*motif* 'PseudoColor)) "pseudo-color")
-		   ((= n (*motif* 'TrueColor)) "true-color")
-		   ((= n (*motif* 'DirectColor)) "direct-color")
-		   (#t "??"))))
       (let* ((cx (snd-gl-context))
 	     (dpy ((*motif* 'XtDisplay) (cadr (main-widgets))))
 	     (version (glXQueryVersion dpy 0 0)))
